import os

#-----------------------------------------------------------------------------------------------------------------------
# Initialise audio file.
#-----------------------------------------------------------------------------------------------------------------------
AUDIO_ROOT = os.path.join(os.path.dirname(os.path.abspath(__file__)), "audio")
AUDIO_PATH = os.path.join(AUDIO_ROOT, "20-20.wav")

#-----------------------------------------------------------------------------------------------------------------------
# Web URL containing the Longplayer audio
#-----------------------------------------------------------------------------------------------------------------------
AUDIO_URL = "https://longplayer.org/audio/20-20.wav.zip"

#-----------------------------------------------------------------------------------------------------------------------
# Audio I/O buffer size, for output to audio hardware.
#-----------------------------------------------------------------------------------------------------------------------
DEFAULT_BUFFER_SIZE = 1024

#-----------------------------------------------------------------------------------------------------------------------
# Audio I/O sample rate
#-----------------------------------------------------------------------------------------------------------------------
SAMPLE_RATE = 44100

#-----------------------------------------------------------------------------------------------------------------------
# The duration of the Longplayer audio basis is precisely 1220 seconds long.
# The audio .wav file is longer because it contains a partial repeat of the first section, allowing the playback
# to loop seamlessly when sections reach the end of the audio.
#-----------------------------------------------------------------------------------------------------------------------
AUDIO_DURATION = 1220.0
AUDIO_DURATION_SAMPLES = int(AUDIO_DURATION * SAMPLE_RATE)

#-----------------------------------------------------------------------------------------------------------------------
# Each playback section is precisely 2 minutes.
#-----------------------------------------------------------------------------------------------------------------------
INCREMENT_INTERVAL = 120.0

#-----------------------------------------------------------------------------------------------------------------------
# Duration for audio fades, at startup and between sections.
#-----------------------------------------------------------------------------------------------------------------------
AUDIO_FADE_TIME = 6.0

#-----------------------------------------------------------------------------------------------------------------------
# Default audio gain, in decibels
#-----------------------------------------------------------------------------------------------------------------------
DEFAULT_AUDIO_GAIN = -0.0

#-----------------------------------------------------------------------------------------------------------------------
# Channels are numbered from the inside (highest frequency) to the outside (lowest frequency).
#-----------------------------------------------------------------------------------------------------------------------
LAYER_RATES = [3/2, 4/3, 1, 3/4, 2/3, 1/2]

#-----------------------------------------------------------------------------------------------------------------------
# Increment steps in samples, on the basis of a sample rate @ 44100kHz.
#-----------------------------------------------------------------------------------------------------------------------
LAYER_INCREMENTS_SAMPLES = [
    329.185022026432,
    19751.3059114067,
    0.2045898210232640,
    46.4418893722809,
    11146.05344934740,
    2593.175981469840
]

#-----------------------------------------------------------------------------------------------------------------------
# Whether to use the pure Python implementation of audio resampling.
# This is less efficient than the libsamplerate implementation, so
# is not presently recommended, particularly for low-CPU devices.
#-----------------------------------------------------------------------------------------------------------------------
USE_INTERNAL_RESAMPLER = False
